Computation times — Group Lasso 1.3.0 documentation

# Computation times

00:02.277 total execution time for auto_examples files:

GroupLasso for logistic regression (`example_logistic_group_lasso.py`) | 00:02.277 | 0.0 MB
GroupLasso for linear regression (`example_group_lasso.py`) | 00:00.000 | 0.0 MB
GroupLasso as a transformer (`example_group_lasso_pipeline.py`) | 00:00.000 | 0.0 MB
GroupLasso for linear regression with dummy variables (`example_sparse_group_lasso.py`) | 00:00.000 | 0.0 MB